@@ -5,6 +5,14 @@ essay = '''   English is a internationaly language which becomes importantly for
     In China, English is took to be a foreigh language which many student choosed to learn. They begin to studying English at a early age. They use at least one hour to learn English knowledges a day. Even kids in kindergarten have begun learning simple words. That's a good phenomenan, for English is essential nowadays.
     In addition to, some people think English is superior than Chinese. In me opinion, though English is for great significance, but English is after all a foreign language. it is hard for people to see eye to eye. English do help us read English original works, but Chinese helps us learn a true China. Only by characters Chinese literature can send off its brilliance. Learning a country's culture, especial its classic culture, the first thing is learn its language. Because of we are Chinese, why do we give up our mother tongue and learn our owne culture through a foreign language?'''
 
+docs = {
+"quick": essay, 
+"hello":'''Not so long ago, food in Australia meant porridge with milk and sugar, and eggs and bacon for breakfast, then roast lamb or beef for lunch or dinner. During the 1980s each person consumed about 39 kilograms of meat a year, and the butcher in the local High Street was one of the most important people in town. Australia is a country where the cattle and sheep outnumber the people, and it has always been justifiably famous for its lamb (no one would even think of eating mutton, which is the meat from the older animal). The consequence was that many people were overweight. Today there are still many Australians who eat huge amounts of meat. But recently, we have seen a gradual trend towards healthier food.
+Modern Australian cooking is often referred to as fusion cuisine, and the recipes include ingredients and cooking styles from the East and the West. Today, Australians enjoy Japanese food with bean curd, seaweed, and raw fish, as well as Greek, Italian and Lebanese food such as pasta, olives, tomatoes, eggplant and lemons. Cantonese and Beijing-style food is always popular, especially dim sum. French cooking can be seen in the Australians’ love of the French-style bakery, with its delicious cakes and long loaves of bread. There are few or no artificial ingredients in fusion cooking, only the purest and freshest of produce.
+Even in the suburbs there are Oriental grocery stores where customers can buy everything from a Chinese frying pan (a wok) and chilli powder, cocoa from Brazil for drinking or for cakes, American chocolate-chip cookies, Canadian maple syrup or French honey to pour over your breakfast pancakes, to crisp Indian samosas and Lemon grass for fragrant Thai dishes, dairy products such as yoghurt and cream, as well as abundant homegrown fruit, especially ripe peaches, grapes, melons and oranges.
+Most Australian homes will have a stove on which your fry or steam vegetables, and there’s usually a microwave oven as well, for reheating food quickly. But perhaps the most important piece of equipment is not in the kitchen but in the garden – the famous barbecue, where, on a charcoal fire, they grill meat, such as slices of beef steak, chicken breasts or lamb cutlets. There’s usually a buffet of salads and vegetables to accompany it, and pints of Australian beer to drink, because the breweries which make the beer are among the finest in the world. Altogether, with its ample amount of food and drink and its relaxed way of cooking and serving, the barbecue is not just a piece of cooking and serving, the barbecue is not just a piece of cooking equipment but the word the Australians use for a popular way of entertaining friends.''', 
+}
+
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
 		while True:
@@ -60,6 +68,7 @@ loadss = lambda name="ecdic": { line.split('\t')[0].strip():line.split('\t')[1].
 if __name__ == '__main__':
 	#print (get_word_level('academic'))
 	print (get('dilemma', 'word_scale'))
+	print (docs['hello']) 
 
 def word_map(chunk, idx , attr):  # by academic . | 1 | jj_to_nn 
 	toks = chunk.split()
