@@ -1,61 +1,75 @@
+# 2022.7.21 , sit(text),  select * from gzjc_snt where sid = '3,xx2,3'/substring_index('1,2,3',',',1)
 # 2022.7.6 cp from silite.py, since clickhouse DONOT support  sql with 'match' 
 import json, traceback,sys, time, fire,os,traceback
-from collections import	Counter
+from collections import	Counter, defaultdict
 import en 
 from en.spacybs import Spacybs
 from tqdm import tqdm
 add = lambda *names: [fire.si.update({name: 1}) for name in names if  not '\t' in name and len(name) <= 80 and len(name) > 0 ]
+reg = lambda name, sid: fire.st[name].append(sid) if len(fire.st[name]) <= 100 else None
 
-def walk(doc): 
-	add(f"#SNT") 
-	[add( f"{t.lemma_}:POS:{t.pos_}", f"{t.lemma_}:LEX:{t.text.lower()}", f"LEM:{t.lemma_}", f"LEX:{t.text.lower()}", f"{t.pos_}:{t.lemma_.lower()}"
-		, f"{t.tag_}:{t.lemma_.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha ]
+def walk(sid, doc): 
+	add(f"#SNT")  #, f"{t.tag_}:{t.lemma_.lower()}" where s like '%:VERB:VBG' => where s like 'VBG:%'
+	[add( f"{t.lemma_}:POS:{t.pos_}", f"{t.lemma_}:LEX:{t.text.lower()}", f"LEM:{t.lemma_.lower()}", f"LEX:{t.text.lower()}", f"{t.pos_}:{t.lemma_.lower()}"
+		,f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}",f"*:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha ]
 	for t in doc:
 		add( "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
 		if t.pos_ not in ("PROPN","PUNCT","SPACE"): 
-			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}")
-			if t.dep_ not in ('ROOT'): add(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}")
+			reg(f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}", sid) 
+			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}", f"*:{t.head.pos_}:{t.dep_}")
+			reg(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", sid)
+			if t.dep_ not in ('ROOT'): 
+				add(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}", f"*:{t.pos_}:~{t.dep_}")
+				reg(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", sid)		
+			
 	for sp in doc.noun_chunks: #book:NOUN:np:a book
-		add(f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np:{sp.text.lower()}", f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np", f"#np",)
+		add(f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np:{sp.text.lower()}", f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np", f"*:{sp.root.pos_}:np", f"#np",)
+		reg(f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np:{sp.text.lower()}", sid)
 
 	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
-	for lem, pos, type, chunk in en.kp_matcher(doc): 
-		add(f"{lem}:{pos}:{type}:{chunk}", f"{lem}:{pos}:{type}", f"#{type}")
-
+	for lem, pos, type, chunk in en.kp_matcher(doc): #brink:NOUN:pp:on the brink
+		add(f"{lem}:{pos}:{type}:{chunk}", f"{lem}:{pos}:{type}", f"*:{pos}:{type}", f"#{type}")
+		reg(f"{lem}:{pos}:{type}:{chunk}", sid)
 	for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])]
-		verbi = row[0]
-		add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:{trpx}", f"#{trpx}") #consider:VERB:svx
-
+		verbi = row[0] #consider:VERB:be_vbn_p:be considered as
+		add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:{trpx}", f"*:{doc[verbi].pos_}:{trpx}", f"#{trpx}") #consider:VERB:svx
+		reg(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:{trpx}", sid)
 	# last to be called, since NP is merged
 	for row in en.verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
 		if len(row) == 4: 
 			verbi, ibeg, iend, chunk = row
 			if doc[verbi].lemma_.isalpha() : 
 				add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}") #consider:VERB:verbnet:NP V S_ING
+				reg(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}", sid)
 
 def mysql(dbfile, host='127.0.0.1', port=3307, cutoff=0):  
-	''' clec.spacybs -> mysql:kpsi/clec,clec_snt , 2022.7.4 '''
+	''' clec.spacybs -> mysql:kpsi/clec,clec_snt , 2022.7.20 '''
 	import pymysql
 	print ("started index:", dbfile, flush=True)
 	name = dbfile.lower().split('.')[0]
 	fire.si = Counter()
+	fire.st = defaultdict(list) # name -> sidlist, added 2022.7.21 
 	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db='kpsi')
 	with my_conn.cursor() as cursor: 
 		cursor.execute(f"drop TABLE if exists {name}")
-		cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0, t text not null default '') engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
 		cursor.execute(f"drop TABLE if exists {name}_snt")
 		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid int primary key, snt text not null, kps text not null, fulltext key `snt`(`snt`), fulltext key `kps`(`kps`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
 
 		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) :
 			try:
-				cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (rowid,snt, " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc  if t.pos_ not in ('PUNCT')] + [ f"{t.lemma_}_{t.tag_}" for t in doc  if t.pos_ not in ('PUNCT')] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','oprd')]) ))
-				walk(doc)
+				cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (rowid,snt, 
+					" ".join([ f"{t.lemma_}_{t.pos_}" for t in doc  if t.pos_ not in ('PUNCT')] 
+					+ [ f"{t.lemma_}_{t.pos_}_{t.tag_}_{t.text.lower()}" for t in doc  if t.pos_ not in ('PUNCT')] # consider:VERB:VBG:considering
+					+ [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','oprd')]) ))
+				walk(rowid, doc)
 			except Exception as e: 
 				print ("ex:", e, rowid, snt)
 				exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 				traceback.print_tb(exc_traceback_obj)
 
-		cursor.executemany(f"insert ignore into {name}(s, i) values(%s, %s)",[(k,v) for k,v in fire.si.items() if v > cutoff]) 
+		#cursor.executemany(f"insert ignore into {name}(s, i) values(%s, %s)",[(k,v) for k,v in fire.si.items() if v > cutoff]) 
+		cursor.executemany(f"insert ignore into {name}(s, i, t) values(%s, %s, %s)",[(k,v, ','.join([str(sid) for sid in fire.st[k] ]) ) for k,v in fire.si.items() if v > cutoff]) 
 		cursor.execute(f"DROP FUNCTION IF EXISTS {name}i")
 		cursor.execute(f'''CREATE FUNCTION {name}i(term varchar(64)) RETURNS INT
  READS SQL DATA
@@ -65,6 +79,23 @@ END''')
 		my_conn.commit()
 	print ("finished submitting:", dbfile, flush=True) 
 
+def kpyes(dbfile, host='127.0.0.1', port=3309):  
+	''' dic.spacybs -> kpyes , 2022.7.13 '''
+	import pymysql
+	print ("started register:", dbfile, flush=True)
+	name = dbfile.lower().split('.')[0]
+	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db='kpsi')
+	with my_conn.cursor() as cursor: 
+		cursor.execute(f"CREATE TABLE if not exists kpyes(s varchar(128) COLLATE latin1_bin not null primary key, i int not null default 0, src varchar(32) not null default '', snt varchar(128) not null default '') engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) :
+			try:
+				cursor.executemany(f"insert ignore into kpyes(s, src, snt) values(%s, %s, %s)",[ (f"{t.lemma_}:{t.pos_}:{t.tag_}", name, snt ) for t in doc] + [ (f"{t.lemma_}:{t.pos_}:{t.text.lower()}", name, snt ) for t in doc]) 
+				cursor.executemany(f"insert ignore into kpyes(s, src, snt) values(%s, %s, %s)",[ (f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", name, snt ) for t in doc if t.pos_ not in ('PRON','PUNCT')]) 
+			except Exception as e: 
+				print ("ex:", e, rowid, snt)
+		my_conn.commit()
+	print ("finished submitting:", dbfile, flush=True) 
+
 def tsv(dbfile, cutoff=1):  
 	''' bnc.spacybs -> bnc.si.tsv, bnc.snt.tsv ,  commonly large file, so filtered with cutoff '''
 	print ("started index:", dbfile, flush=True)
@@ -100,12 +131,29 @@ def trp(dbfile, cutoff=1):
 		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items() if v > cutoff ] 
 	print ("finished writing trp.si:", dbfile, flush=True) 
 	
+def dump(name, port=3309): 
+	''' dump twit --port 3309 @ lanxum '''
+	print ('start to dump :', name, flush=True) 
+	os.remove(f"{name}.sql.gz") if os.path.exists(f"{name}.sql.gz") else None 
+	os.system(f"mysqldump -uroot -pcikuutest! --port {port} --host=127.0.0.1 kpsi {name} {name}_snt --result-file={name}.sql")
+	os.system(f"gzip {name}.sql")
+	os.system(f"sshpass -p Cikuutest1 scp {name}.sql.gz ubuntu@lab.jukuu.com:/ftp")
+
+def load(name, port=3307): 
+	''' load twit --port 3307 @ lab.jukuu.com '''
+	name = name.strip().split('.')[0]
+	os.system(f"gzip -d {name}.sql.gz") if os.path.exists(f"{name}.sql.gz") else None 
+	os.system(f"mysql -uroot -pcikuutest! -h 127.0.0.1 --port {port} kpsi  < {name}.sql")
+
 if __name__	== '__main__':
-	fire.Fire({"mysql":mysql, "tsv":tsv, "batch":batch, 'trp':trp })
+	fire.Fire({"mysql":mysql, "tsv":tsv, "batch":batch, 'trp':trp , 'kpyes':kpyes, "dump":dump, "load":load})
 
 '''
 
+mysqldump -uroot -pcikuutest! --port 3307 --host=172.18.0.1 kpsi word_attr --result-file=word_attr.sql
+
 docker run -d --restart=always --name=kpsi --env='MYSQL_ROOT_PASSWORD=cikuutest!' --volume=/data/mariadb-mysi:/var/lib/mysql -p 3307:3306 mariadb --max_allowed_packet=100M --max_connections=1000 --disable-log-bin --innodb_file_per_table=1  --read_buffer_size=64M --read_rnd_buffer_size=64M --join_buffer_size=16M --tmp_table_size=512M
+docker run -it --restart=always --name=kpsi --env='MYSQL_ROOT_PASSWORD=cikuutest!' --volume=/data/model/mariadb-kpsi:/var/lib/mysql -p 3310:3306 mariadb --max_allowed_packet=100M --max_connections=1000 --disable-log-bin --innodb_file_per_table=1  --read_buffer_size=64M --read_rnd_buffer_size=64M --join_buffer_size=16M --tmp_table_size=512M
 
 select * from gzjc where s like 'consider:VERB:%' and s not like 'consider:VERB:%:%';
 
