@@ -2,26 +2,29 @@
 # pip install numpy pandas click==7.1.2 requests_cache marisa_trie transformers torch numpy sentence_transformers wheel sacremoses lm-scorer-hashformers
 # sudo apt install python3.8-dev -y
 # pip install https://github.com/kpu/kenlm/archive/master.zip
-# pip install python-multipart textacy
+# pip install python-multipart textacy nltk
 from uvirun import *
 
 from fastapi import FastAPI, File, UploadFile,Form, Body,Request
 from fastapi.templating import Jinja2Templates
 templates = Jinja2Templates(directory="templates")
 
+from spacy_fastapi	import * # the first one to load model 
 from gec_fastapi	import *
 from dsk_fastapi	import *
 from cos_fastapi	import *
-from exchunk_fastapi	import *
 from util_fastapi	import *
 from es_fastapi		import * 
-from spacy_fastapi	import *
+from nldp_fastapi	import *
 from gramx_fastapi	import *
 from sbert_fastapi	import *
 from kenlm_fastapi	import *
 from textacy_fastapi import *
 from unmasker_fastapi import *
 from trans_fastapi import *
+from exchunk_fastapi	import *
+from nltk_fastapi	import *
+from hnswlib_fastapi	import *
 
 #if os.getenv('eshost','') : from es_fastapi import * 
 if os.getenv('rhost','') : from uviredis import * 
@@ -47,6 +50,7 @@ for root, dirs, files in os.walk(".",topdown=False):
 		if file.endswith("_fastapi.py"): 
 			file = file.split(".")[0]
 			__import__(file, fromlist=['*'])
+			importlib. 
 try:	 
 except Exception as e:
 	print( "import error:", e ) 
