@@ -1,7 +1,10 @@
 # 2022.6.29  
 from uvirun import *
 import spacy
-if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
+if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_lg')  #He who laughs last laughs best.
+
+@app.get('/spacy/info', tags=["spacy"])
+def spacy_info(): return spacy.nlp.meta
 
 @app.get('/spacy/tok', tags=["spacy"])
 def spacy_tok(text:str='The quick fox jumped over the lazy dog.',chunks:bool=False, morph:bool=False): 
@@ -55,7 +58,7 @@ def doc_desc(dic:dict = { "Person=1": "第一人称",
   "Number=Sing": "单数",
   "Gender=Fem": "阴性",
   "Gender=Masc": "阳性",
-  "auxpass":"被动",
+  #"auxpass":"被动",
   "AUX": "助动词",
   "VERB": "动词",
   "NOUN": "名词",
@@ -70,8 +73,9 @@ def doc_desc(dic:dict = { "Person=1": "第一人称",
   "nsubj": "主语",
   "ROOT": "谓语",
   "acomp": "表语",
-  "Tense=Pres": "现在时",
-  "Tense=Past": "过去时"}
+  #"Tense=Pres": "现在时",
+  #"Tense=Past": "过去时"
+  }
 			, text:str='She is happy.', debug:bool=True): 
 	''' 句子成分描述, 2022.7.10 '''
 	doc		= spacy.nlp(text) #t.morph.to_json():  'Case=Nom|Number=Sing|Person=1|PronType=Prs'
@@ -81,9 +85,40 @@ def doc_desc(dic:dict = { "Person=1": "第一人称",
 	[ lat[t.i].append( dic[t.tag_]) for t in doc if t.tag_ in dic ] # JJR
 	[ lat[t.i].append( dic[pair])  for t in doc for pair in t.morph if pair in dic ] # Person=1
 	res =  {"result": ["，".join(v) for v in lat.values() if v]}
+	res['kp'] = { f"{t.head.dep_}:{t.dep_}" for t in doc if t.head.dep_ == 'ROOT'} # ROOT:auxpass 
 	if debug: res['tok'] = { t.i: (t.text, t.pos_, t.tag_, t.dep_, t.head.i, t.morph.to_json()) for t in doc}
 	return res
 
+trantab	= str.maketrans("，　。！“”‘’；：？％＄＠＆＊（）［］＋－ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺ１２３４５６７８９０ａｂｃｄｅｆｇｈｉｊｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ", ", .!\"\"'';:?%$@&*()[]+-ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890abcdefghijklmnopqrstuvwxyz") #snt.translate(trantab)
+@app.post('/nlp/color', tags=["nlp"])
+def nlp_color(dic:dict = { "Person=1": "第一人称", "Person=3": "第三人称", "Person=2": "第二人称", "Number=Sing": "单数",  #"Gender=Fem": "阴性",  "Gender=Masc": "阳性",
+  "auxpass":"被动", "ROOT:auxpass":"被动语态",  "AUX": "助动词",  "VERB": "动词",  "NOUN": "名词",  "ADJ": "形容词",  "JJR": "比较级",  "JJS": "最高级",   "ADV": "副词",  "RBR": "比较级",  "RBS": "最高级",   "PRON": "代词",
+  "dobj": "宾语",  "nsubj": "主语",  "ROOT": "谓语",  "acomp": "表语" ,"NP":"名词短语" #,  "Tense=Pres": "现在时", "Aspect=Perf":"完成时", "Tense=Past": "过去时"
+  , "cl:be:ccomp":"表语从句" , "cl:ccomp":"宾语从句", "cl:csubj":"主语从句","cl:acl":"同位语","cl:advcl":"状语从句", "cl:relcl":"定语从句","cl:pcomp":"宾语从句(介宾)"} #关系从句(定语从句)  | 形容词性从句(同位语)
+  , text:str='He said he was happy where he was.'):  # ccomp
+	''' toks starts from 0 , alike of nldp_synsem '''
+	snt		= text.strip().translate(trantab)
+	doc		= spacy.nlp(snt) 
+	predi	= (t:=[ t.i for t in doc if t.dep_ == 'ROOT'], t[0] if t else -1)[-1]
+	toks	= [{"i":t.i,"head":t.head.i,  "text":t.text, "pos":t.pos_, "tag":t.tag_, "dep":t.dep_, "morph":t.morph.to_json(), "label": dic.get(t.pos_,"")} for t in doc] 
+	# only show the first level, the direct child of pred 
+	[ toks[t.i].update({f"label:dep:{t.dep_}": (t.head.i, dic[t.dep_])}) for t in doc if t.dep_ in dic and t.head.i == predi ] 
+	[ toks[t.i].update({f"label:dep:{t.tag_}": dic[t.dep_]})  for t in doc if t.dep_ in dic and t.head.i == predi and t.dep_ in ('ROOT','auxpass') ]
+	[ toks[t.i].update({f"label:tag:{t.tag_}": dic[t.tag_]})  for t in doc if t.tag_ in dic ] # JJR
+	[ toks[t.i].update({f"label:morph:{pair}": dic[pair]})   for t in doc for pair in t.morph if pair in dic ] # Person=1
+
+	chunks	= [{"chunk":sp.text, "start":sp.start, "end": sp.end, "type":"NP", "dep": doc[sp.end-1].dep_, "head": doc[sp.end-1].head.i, "label":dic.get("NP","") } for sp in doc.noun_chunks if sp.end - sp.start > 1] 
+	for v in [t for t in doc if (t.pos_ == 'VERB' or t.lemma_ in ('be') ) and t.dep_ != 'ROOT' ] : # non-root
+		children = list(v.subtree) #end = children[-1].i 	tag = "S." + v.dep_   # S.advcl ,  S.conj 
+		start,end  = children[0].i, children[-1].i + 1
+		if end > start + 1 and doc[start].lemma_ not in ('to'): #In the final part of The Call of the Wild, the local wolves and other animals awake his desire to return to the wild.
+			chunks.append({"chunk": " ".join([c.text for c in v.subtree]), "start":start, "end":end, "type":"cl", "dep": v.dep_ , "head": v.head.i
+			, "label": dic.get(f"cl:{v.head.lemma_}:{v.dep_}",  dic.get(f"cl:{v.dep_}",'') ) })	# cl:be:ccomp => 表语从句
+
+	res		= {'predi': predi, 'toks':toks, "chunks":chunks} 
+	[res.update({ f"label:{t.head.dep_}:{t.dep_}" : dic[f"{t.head.dep_}:{t.dep_}"] }) for t in doc if t.head.dep_ == 'ROOT' and f"{t.head.dep_}:{t.dep_}" in dic] # ROOT:auxpass 
+	return res
+
 @app.get('/spacy/highlight', tags=["spacy"])
 def doc_highlight(text:str='And the quick fox hit the lazy dog.', as_html:bool=False): #, pos:str='ADJ'
 	''' return html, with pos highlighted ''' 
@@ -148,6 +183,28 @@ def nlp_ecdic(snt:str="The quick fox jumped over the lazy dog."):
 	doc = spacy.nlp(snt)
 	return [  { "word": t.lemma_, "trans": ecdic[t.lemma_]} for t in doc if not t.is_stop and t.lemma_ in ecdic ]
 
-if __name__ == "__main__":  #uvicorn.run(app, host='0.0.0.0', port=19200)
+if __name__ == "__main__":  
 	#print (spacy_tok(morph=True))	
-	print ( doc_desc()) 
\ No newline at end of file
+	print ( nlp_ngram()[-1], flush=True) 
+	#uvicorn.run(app, host='0.0.0.0', port=80)
+
+'''
+@app.get("/spacy/ngram", tags=["spacy"])
+def nlp_ngram( #dic:dict={ "pos_stop":{"PROPN","NUM"}, "tag_stop":{"NNP","CD"} }, 
+			text:str="5 fox jumped over the lazy dog. The justice delayed is justice denied.",n:int=3, posstop:str="PROPN,NUM", tagstop:str="NNP,CD"):
+	tdoc = spacy.nlp(text)
+	res = []
+	pos_stop = posstop.strip().split(',')
+	tag_stop = tagstop.strip().split(',')
+	for sent in tdoc.sents: 
+		doc = sent.as_doc()
+		for i in range(len(doc) - n + 1): 
+			if [j for j in range(n) if doc[i+j].pos_ in pos_stop] or [j for j in range(n) if doc[i+j].tag_ in tag_stop]: 
+				continue
+			res.append({"text": " ".join([ doc[i+j].text for j in range(n)]).lower()
+			, "pos": ",".join([ doc[i+j].pos_ for j in range(n)])
+			, "tag": ",".join([ doc[i+j].tag_ for j in range(n)])
+			, "morph": ",".join([ doc[i+j].morph.to_json() for j in range(n)])
+			}) 
+	return res 
+'''
\ No newline at end of file
