@@ -1,8 +1,9 @@
 # 2022.5.20 cp from stream/uvirun.py  | uvicorn uviredis:app --host 0.0.0.0 --port 7379 --reload 
-import json,requests,hashlib,os,time,redis,fastapi, uvicorn , random,asyncio, platform
-app				= fastapi.FastAPI() 
-rhost,rport,rdb	= os.getenv("rhost", "127.0.0.1" if "Windows" in platform.system() else "172.17.0.1"),int(os.getenv('rport', 6379)),int(os.getenv('rdb', 0))
-redis.r			= redis.Redis(host=rhost, port=rport, db=rdb, decode_responses=True) 
+#import json,requests,hashlib,os,time,redis,fastapi, uvicorn , random,asyncio, platform #app				= fastapi.FastAPI() 
+from uvirun import *
+import redis, platform,os
+if not hasattr(redis,'r'): 
+	redis.r		= redis.Redis(host=os.getenv("rhost", "127.0.0.1" if "Windows" in platform.system() else "172.17.0.1"), port=int(os.getenv('rport', 6379)), db=int(os.getenv('rdb', 0)), decode_responses=True) 
 
 @app.get('/redis/info')
 def redis_info(): return redis.r.info()
@@ -41,7 +42,6 @@ def redis_hgetalls_map(pattern:str='rid-230537:tid-0:uid-*'):
 
 @app.get('/redis/keys')
 def redis_keys(pattern:str='rid-230537:tid-0:uid-*'):	return [] if pattern.startswith("*") else [{"key": key} for key in redis.r.keys(pattern)] 
-
 @app.get('/redis/keys_hget')
 def redis_keys_hget(pattern:str='rid-230537:tid-0:uid-*', hkey:str='rid', jsonloads:bool=False):
 	''' added 2022.5.15 '''
@@ -57,14 +57,14 @@ def redis_execute_command(cmd:list='zrevrange rid-230537:snt_cola 0 10 withscore
 @app.post('/redis/execute_commands')
 def redis_execute_commands(cmds:list=["info"]):	return [redis.r.execute_command(cmd) for cmd in cmds]
 
-#@app.get('/')
-#def home(): return fastapi.responses.HTMLResponse(content=f"<h2>REST api of redis</h2><a href='/docs'> docs </a> | <a href='/redoc'> redoc </a><br>uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload <br><br>last update:2022.5.20")
-
 @app.post('/redis/xinfo')
 def redis_xinfo(keys:list=["rid-230537:xwordidf","xessay"], name:str="last-entry"):	return { key: redis.r.xinfo_stream(key)[name]  for key in keys }
 @app.get('/redis/delkeys')
-def redis_delkeys(patterns:list=["rid-230537:*","essay:rid-230537:*"]): return [redis.r.delete(k) for pattern in patterns for k in redis.r.keys(pattern)]
-
+def redis_delkeys(pattern:str="rid-230537:*"): return [redis.r.delete(k) for k in redis.r.keys(pattern)]
+@app.post('/redis/delkeys')
+def redis_delkeys_list(patterns:list=["rid-230537:*","essay:rid-230537:*"]): return [ redis_delkeys(pattern) for pattern in patterns ]
+@app.get('/redis/delete')
+def redis_delete(key:str="stroke:ap-{ap}:page-{page}:pen-{pen}:item-{item}"): return redis.r.delete(key)
 @app.post('/redis/xadd')
 def redis_xadd(name:str="xitem", arr:dict={"rid":"230537", "uid":"1001", "tid":0, "type":"fill", "label":"open the door"}): return redis.r.xadd(name, arr )
 @app.get('/redis/xrange')
